__author__ = 'California Audio Visual Preservation Project'

class FormatException(Exception):
    def __init__(self, value):
         self.value = value

    def __str__(self):
        return self.value


class NoDataException(Exception):
    def __init__(self, value):
         self.value = value

    def __str__(self):
        return self.value


#!/usr/bin/python
# -*- coding: UTF-8 -*-
from abc import ABCMeta
class AUXMetadata(object):
    __metaclass__ = ABCMeta
    def getAuxLens(self):
        return self.___auxLens

    def getAuxSerialNumber(self):
        return self.___auxSerialNumber

    def __init__(self):
        self.___auxLens = None
        self.___auxSerialNumber = None




#!/usr/bin/python
# -*- coding: UTF-8 -*-
from abc import ABCMeta
class DublinCoreMetadata(object):
    __metaclass__ = ABCMeta
    def __init__(self):
        self.___dcContributor = None
        self.___dcCoverage = None
        self.___dcCreator = None
        self.___dcDate = None
        self.___dcDescription = None
        self.___dcFormat = None
        self.___dcIdentifier = None
        self.___dcLanguage = None
        self.___dcPublisher = None
        self.___dcRelation = None
        self.___dcRights = None
        self.___dcSource = None
        self.___dcSubject = None
        self.___dcTitle = None
        self.___dcType = None

    def getDCContributor(self):
        pass

    def getDCCoverage(self):
        pass

    def getDCCreator(self):
        pass

    def getDCDate(self):
        pass

    def getDCDescription(self):
        pass

    def getDCFormat(self):
        pass

    def getDCIdentifier(self):
        pass

    def getDCLanguage(self):
        pass

    def getDCPublisher(self):
        pass

    def getDCRelation(self):
        pass

    def getDCRights(self):
        pass

    def getDCSource(self):
        pass

    def getDCSubject(self):
        pass

    def getDCTitle(self):
        pass

    def getDCType(self):
        pass




#!/usr/bin/python
# -*- coding: UTF-8 -*-

# from onesheet.XMPVideoMetadata import XMPMetadata
from onesheet.VideoMetadata import VideoMetadata
from onesheet.AudioMetadata import AudioMetadata

# class VideoObject(AudioMetadata, VideoMetadata, XMPVideoMetadata):
class VideoObject(VideoMetadata, AudioMetadata):

    def __init__(self, filename):
        VideoMetadata.__init__(self, filename)

    pass



#!/usr/bin/python
# -*- coding: UTF-8 -*-
from onesheet import ClassFileMetadata
from abc import ABCMeta

class DocumentMetadata(ClassFileMetadata):
    __metaclass__ = ABCMeta
    def getDocumentType(self):
        return self.___documentType

    def setDocumentType(self, aDocumentType):
        """@ReturnType void"""
        self.___documentType = aDocumentType

    def __init__(self):
        self.___documentType = None




#!/usr/bin/python
# -*- coding: UTF-8 -*-
from abc import ABCMeta

class PhotoshopMetadata(object):
    __metaclass__ = ABCMeta
    def __init__(self):
        self.___photoshopAuthorsPosition = None
        self.___photoshopCaptionWriter = None
        self.___photoshopCategory = None
        self.___photoshopCity = None
        self.___photoshopCountry = None
        self.___photoshopCredit = None
        self.___photoshopDateCreated = None
        self.___photoshopHeadline = None
        self.___photoshopInstructions = None
        self.___photoshopSource = None
        self.___photoshopState = None
        self.___photoshopSupplementalCategories = None
        self.___photoshopTransmissionReference = None
        self.___photoshopUrgency = None

    def getPhotoshopAuthorsPosition(self):
        return self.___photoshopAuthorsPosition

    def getPhotoshopCaptionWriter(self):
        return self.___photoshopCaptionWriter

    def getPhotoshopCategory(self):
        return self.___photoshopCategory

    def getPhotoshopCity(self):
        return self.___photoshopCity

    def getPhotoshopCountry(self):
        return self.___photoshopCountry

    def getPhotoshopCredit(self):
        return self.___photoshopCredit

    def getPhotoshopDateCreated(self):
        return self.___photoshopDateCreated

    def getPhotoshopHeadline(self):
        return self.___photoshopHeadline

    def getPhotoshopInstructions(self):
        return self.___photoshopInstructions

    def getPhotoshopSource(self):
        return self.___photoshopSource

    def getPhotoshopState(self):
        return self.___photoshopState

    def getPhotoshopSupplementalCategories(self):
        return self.___photoshopSupplementalCategories

    def getPhotoshopTransmissionReference(self):
        return self.___photoshopTransmissionReference

    def getPhotoshopUrgency(self):
        return self.___photoshopUrgency

